import { NextFunction, Request, Response } from 'express';
export interface MetricsMiddlewareOptions {
    /**
     * Whether to publish metrics for each HTTP response status code.
     *
     * Metrics will appear in CloudWatch like e.g. 'StatusCode200'.
     *
     * @default true
     */
    statusCodeMetric?: boolean;
    /**
     * Whether to publish `ClientError` metric based on response HTTP status code.
     *
     * Useful if you want to calculate your availability metric.
     *
     * @default true
     */
    clientErrorMetric?: boolean;
    /**
     * Whether to publish `ServerError` metric based on response HTTP status code.
     *
     * Useful if you want to calculate your availability metric.
     *
     * @default true
     */
    serverErrorMetric?: boolean;
    /**
     * Whether to publish `RequestDuration` metric based on the time between the request
     * coming into `metricsMiddleware` and when the response
     * has finished being written out to the connection, in milliseconds.
     *
     * @default true
     */
    durationMetric?: boolean;
    /**
     * Whether to set `RemoteAddress` property to EMF logs.
     *
     * @default false
     */
    ipProperty?: boolean;
    /**
     * Whether to set `UserAgent` property to EMF logs.
     *
     * @default false
     */
    userAgentProperty?: boolean;
}
export declare const metricsMiddleware: (options?: MetricsMiddlewareOptions) => (req: Request, res: Response, next: NextFunction) => void;
