"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.metricsMiddleware = void 0;
const aws_embedded_metrics_1 = require("aws-embedded-metrics");
const onFinished = require("on-finished");
function getRequestDuration(req) {
    if (!req._startAt) {
        return;
    }
    const elapsed = process.hrtime(req._startAt);
    return (elapsed[0] * 1e3) + (elapsed[1] * 1e-6);
}
function getIp(req) {
    return req.ip ||
        (req.connection && req.connection.remoteAddress) ||
        undefined;
}
const metricsMiddleware = (options = {}) => {
    const { statusCodeMetric = true, clientErrorMetric = true, serverErrorMetric = true, durationMetric = true, ipProperty = false, userAgentProperty = false, } = options;
    return (req, res, next) => {
        if (durationMetric) {
            req._startAt = process.hrtime();
        }
        req.metrics = (0, aws_embedded_metrics_1.createMetricsLogger)();
        if (ipProperty) {
            req.metrics.setProperty('RemoteAddress', getIp(req));
        }
        if (userAgentProperty) {
            req.metrics.setProperty('UserAgent', req.headers['user-agent']);
        }
        onFinished(res, () => {
            const { metrics } = req;
            const { statusCode } = res;
            const duration = getRequestDuration(req);
            if (duration) {
                req.metrics.putMetric('RequestDuration', duration, aws_embedded_metrics_1.Unit.Milliseconds);
            }
            if (statusCodeMetric) {
                metrics.putMetric(`StatusCode${statusCode}`, 1, aws_embedded_metrics_1.Unit.Count);
            }
            if (clientErrorMetric) {
                metrics.putMetric('ClientError', statusCode >= 400 && statusCode < 500 ? 1 : 0, aws_embedded_metrics_1.Unit.Count);
            }
            if (serverErrorMetric) {
                metrics.putMetric('ServerError', statusCode >= 500 ? 1 : 0, aws_embedded_metrics_1.Unit.Count);
            }
            metrics.flush()
                // eslint-disable-next-line @typescript-eslint/no-empty-function
                .catch(() => { })
                .finally(() => next());
        });
        next();
    };
};
exports.metricsMiddleware = metricsMiddleware;
